function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var react = require('react');
var validator = _interopDefault(require('validator'));

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _unsupportedIterableToArray(o, minLen) {
  if (!o) return;
  if (typeof o === "string") return _arrayLikeToArray(o, minLen);
  var n = Object.prototype.toString.call(o).slice(8, -1);
  if (n === "Object" && o.constructor) n = o.constructor.name;
  if (n === "Map" || n === "Set") return Array.from(o);
  if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen);
}

function _arrayLikeToArray(arr, len) {
  if (len == null || len > arr.length) len = arr.length;

  for (var i = 0, arr2 = new Array(len); i < len; i++) arr2[i] = arr[i];

  return arr2;
}

function _createForOfIteratorHelperLoose(o, allowArrayLike) {
  var it;

  if (typeof Symbol === "undefined" || o[Symbol.iterator] == null) {
    if (Array.isArray(o) || (it = _unsupportedIterableToArray(o)) || allowArrayLike && o && typeof o.length === "number") {
      if (it) o = it;
      var i = 0;
      return function () {
        if (i >= o.length) return {
          done: true
        };
        return {
          done: false,
          value: o[i++]
        };
      };
    }

    throw new TypeError("Invalid attempt to iterate non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method.");
  }

  it = o[Symbol.iterator]();
  return it.next.bind(it);
}

var validate = function validate(_ref) {
  var value = _ref.value,
      checks = _ref.checks,
      customValidator = _ref.customValidator;

  if (checks) {
    checks = checks.split('|');

    for (var _iterator = _createForOfIteratorHelperLoose(checks), _step; !(_step = _iterator()).done;) {
      var check = _step.value;

      var _check$split = check.split(':'),
          checkKey = _check$split[0],
          checkConstraint = _check$split[1];

      switch (checkKey.trim()) {
        case 'required':
          if (!value) return 'Required.';
          break;

        case 'match':
          if (value && !validator.matches(value, checkConstraint.trim())) return "Doesn't match " + checkConstraint.trim();
          break;

        case 'date':
          if (value && validator.toDate(value) === null) return "Not a valid date.";
          break;

        case 'email':
          if (value && !validator.isEmail(value)) return 'Not a valid email.';
          break;

        case 'alpha':
          if (value && !validator.isAlpha(value)) return 'Only Alphabets allowed.';
          break;

        case 'alpha_num':
          if (value && !validator.isAlphanumeric(value)) return 'Only Alphabets and Numbers allowed';
          break;

        case 'url':
          if (value && !validator.isURL(value)) return 'Not a valid URL.';
          break;

        case 'num':
          if (value && !validator.isNumeric(value)) return 'Only Numbers allowed.';
          break;

        case 'tel':
          if (value && !validator.isMobilePhone(value)) return 'Not a valid mobile phone number.';
          break;

        case 'min':
          if (value && value.length < parseInt(checkConstraint)) return "Minimium of " + checkConstraint + " character required.";
          break;

        case 'max':
          if (value && value.length > parseInt(checkConstraint)) return "Maximium of " + checkConstraint + " character required.";
          break;
      }
    }
  }

  return typeof customValidator === 'function' && customValidator(value);
};

var reducer = function reducer(state, action) {
  var _extends2, _values;

  switch (action.type) {
    case 'UPDATE_FIELD':
      return _extends({}, state, {
        errors: _extends({}, state.errors, (_extends2 = {}, _extends2[action.payload.key] = validate({
          key: action.payload.key,
          value: action.payload.value,
          checks: state.checks[action.payload.key],
          customValidator: state.validators[action.payload.key]
        }), _extends2)),
        values: (_values = {}, _values[action.payload.key] = action.payload.value, _values)
      });
  }
};

var useFormValidator = function useFormValidator(inputs) {
  var initial = {
    checks: {},
    values: {},
    validators: {},
    errors: {}
  };

  for (var key in inputs) {
    initial.checks[key] = inputs[key].checks;
    initial.validators[key] = inputs[key].validate;
    initial.values[key] = inputs[key].value;
    initial.errors[key] = '';
  }

  var _useReducer = react.useReducer(reducer, initial),
      fields = _useReducer[0],
      setFormField = _useReducer[1];

  var updateField = function updateField(e) {
    validateField({
      key: e.target.name,
      value: e.target.value
    });
  };

  var validateField = function validateField(_ref2) {
    var key = _ref2.key,
        value = _ref2.value;

    if (fields.values[key] === undefined) {
      throw Error("Field with key \"" + key + "\" not found, please make sure it is define in as follows:\n      useFormValidator({\n        " + key + ": {\n          value: \"\",\n          error: \"\",\n          checks: \"required\"\n        }\n      })\n      ");
    }

    setFormField({
      type: 'UPDATE_FIELD',
      payload: {
        key: key,
        value: value
      }
    });
  };

  var isFieldValid = function isFieldValid(key) {
    validateField({
      key: key,
      value: fields.values[key]
    });
    if (fields.errors[key]) return false;
    return true;
  };

  var isAllFieldsValid = function isAllFieldsValid() {
    var valid = true;

    for (var _key in fields.values) {
      var error = validate({
        value: fields.values[_key],
        checks: fields.checks[_key]
      });
      if (error) valid = false;
      setFormField({
        type: 'UPDATE_FIELD',
        payload: {
          key: _key,
          value: fields.values[_key],
          checks: fields.checks[_key]
        }
      });
    }

    return valid;
  };

  return {
    values: fields.values,
    errors: fields.errors,
    isAllFieldsValid: isAllFieldsValid,
    isFieldValid: isFieldValid,
    updateField: updateField
  };
};

module.exports = useFormValidator;
//# sourceMappingURL=index.js.map
